<?php
// Copyright (C) <2015-present>  <it-novum GmbH>
//
// This file is licensed under the terms of the openITCOCKPIT Enterprise Edition license agreement.
// The license agreement and license key were sent with the order confirmation.


declare(strict_types=1);

namespace VMWAREModule\Controller;

use App\itnovum\openITCOCKPIT\Wizard\CreateService;
use App\itnovum\openITCOCKPIT\Wizard\UpdateHost;
use App\Model\Entity\Host;
use App\Model\Table\HostsTable;
use App\Model\Table\HosttemplatesTable;
use App\Model\Table\ServicesTable;
use App\Model\Table\ServicetemplatesTable;
use App\Model\Table\WizardAssignmentsTable;
use Cake\Http\Exception\NotFoundException;
use Cake\ORM\TableRegistry;
use Cake\Utility\Hash;
use itnovum\openITCOCKPIT\Core\ValueObjects\User;
use VMWAREModule\Form\VMWareForm;


/**
 * Class WizardsController
 * @package VMWAREModule\Controller
 */
class WizardsController extends AppController {


    /**
     * @param null $hostId
     */
    public function vmware($hostId = null) {
        if (!$this->isApiRequest()) {
            //Only ship HTML template for angular
            return;
        }
        /** @var WizardAssignmentsTable $WizardAssignmentsTable */
        $WizardAssignmentsTable = TableRegistry::getTableLocator()->get('WizardAssignments');
        $wizards = $WizardAssignmentsTable->getAvailableWizards($this->PERMISSIONS);
        /** @var ServicesTable $ServicesTable */
        $ServicesTable = TableRegistry::getTableLocator()->get('Services');
        /** @var HostsTable $HostsTable */
        $HostsTable = TableRegistry::getTableLocator()->get('Hosts');


        if ($this->request->is('get') && $this->isAngularJsRequest()) {
            if (!$HostsTable->existsById($hostId)) {
                throw new NotFoundException();
            }
            $host = $HostsTable->getHostByIdForPermissionCheck($hostId);
            if (!$this->allowedByContainerId($host->getContainerIds())) {
                $this->render403();
                return;
            }
            $hostCustomVariables = $HostsTable->get($hostId, [
                'contain' => [
                    'Customvariables'
                ]
            ])->getCustomvariablesForCfg();

            $username = '';
            if (!empty($hostCustomVariables['_USERNAME'])) {
                $username = $hostCustomVariables['_USERNAME'];
            }
            $password = '';
            if (!empty($hostCustomVariables['_PASSWORD'])) {
                $password = $hostCustomVariables['_PASSWORD'];
            }
            $vcenter = '';
            if (!empty($hostCustomVariables['_VCENTER'])) {
                $password = $hostCustomVariables['_VCENTER'];
            }

            $this->set('username', $username);
            $this->set('password', $password);
            $this->set('vcenter', $vcenter);

            $typeId = $this->request->getQuery('typeId');
            //Return vmware wizard data
            $servicetemplates = [];
            $wizardAssignments = [];
            $vmwareWizardData = $wizards[$typeId] ?? null;
            if ($vmwareWizardData) {
                if ($WizardAssignmentsTable->existsByUuidAndTypeId($vmwareWizardData['uuid'], $typeId)) {
                    $wizardAssignments = Hash::merge($vmwareWizardData, $WizardAssignmentsTable->getWizardByUuidForEdit($vmwareWizardData['uuid']));
                }
            }
            if (!empty($wizardAssignments['servicetemplates']['_ids'])) {
                /** @var ServicetemplatesTable $ServicetemplatesTable */
                $ServicetemplatesTable = TableRegistry::getTableLocator()->get('Servicetemplates');
                $servicetemplates = $ServicetemplatesTable->getServicetemplatesFoWizardDeploy(
                    $wizardAssignments['servicetemplates']['_ids'],
                    $this->MY_RIGHTS
                );
            }

            $servicesNamesForExistCheck = $ServicesTable->getServiceNamesByHostIdForWizard($hostId);


            $this->set('servicetemplates', $servicetemplates);
            $this->set('servicesNamesForExistCheck', $servicesNamesForExistCheck);

            $this->viewBuilder()->setOption('serialize', [
                'servicetemplates',
                'servicesNamesForExistCheck',
                'username',
                'password',
                'vcenter'
            ]);

            return;
        }
        if ($this->request->is('post') && $this->isAngularJsRequest()) {
            $hostId = $this->request->getData('host_id', 0);
            $typeId = $this->request->getData('typeId');

            if (!$HostsTable->existsById($hostId)) {
                throw new NotFoundException();
            }

            $host = $HostsTable->getHostByIdForPermissionCheck($hostId);
            if (!$this->allowedByContainerId($host->getContainerIds())) {
                $this->render403();
                return;
            }


            $VMWareForm = new VMWareForm();
            $data = $this->request->getData(null, []);
            $VMWareForm->execute($data);

            if (!empty($VMWareForm->getErrors())) {
                $this->response = $this->response->withStatus(400);
                $this->set('error', $VMWareForm->getErrors());
                $this->viewBuilder()->setOption('serialize', ['error']);
                return;
            }

            //Wizard validation successfully - update host and create services
            $User = new User($this->getUser());

            /** @var HosttemplatesTable $HosttemplatesTable */
            $HosttemplatesTable = TableRegistry::getTableLocator()->get('Hosttemplates');

            // Get host and host template for merge
            $host = $HostsTable->getHostForEdit($hostId);
            $hosttemplate = $HosttemplatesTable->getHosttemplateForDiff($host['Host']['hosttemplate_id']);

            //Update custom variables
            $hostCustomVariablestoCheck = [
                'USERNAME' => 'username',   //vCenter only | esx directly
                'PASSWORD' => 'password'    //vCenter only | esx directly
            ];

            if ($typeId === 'vmware-through-vcenter') {
                $hostCustomVariablestoCheck['VCENTER'] = 'vcenter';    //vCenter only
            }
            //Update host with changelog
            $hostEntity = UpdateHost::save(
                $host,
                $hosttemplate,
                $data,
                $hostCustomVariablestoCheck,
                $HostsTable,
                $User
            );

            if ($hostEntity instanceof Host) {
                //Host updated successfully - create services
                /** @var ServicetemplatesTable $ServicetemplatesTable */
                $ServicetemplatesTable = TableRegistry::getTableLocator()->get('Servicetemplates');

                // Save default VMWare services
                CreateService::saveMany(
                    $hostEntity,
                    $data['services'],
                    $data,
                    [],
                    $HostsTable,
                    $HosttemplatesTable,
                    $ServicesTable,
                    $ServicetemplatesTable,
                    $User
                );
            }
        }
        return;
    }
}