<?php
// Copyright (C) <2015-present>  <it-novum GmbH>
//
// This file is licensed under the terms of the openITCOCKPIT Enterprise Edition license agreement.
// The license agreement and license key were sent with the order confirmation.

namespace VMWAREModule\Lib\InitialDatabase;

use App\Model\Table\CommandsTable;
use App\Model\Table\ServicetemplategroupsTable;
use App\Model\Table\ServicetemplatesTable;
use App\Model\Table\WizardAssignmentsTable;
use itnovum\openITCOCKPIT\InitialDatabase\Importer;

/**
 * Class TemplateImport
 * @package VMWAREModule\Lib\InitialDatabase
 */
class TemplateImport extends Importer {

    /**
     * @var CommandsTable
     */
    private $CommandsTable;

    /**
     * @var ServicetemplatesTable
     */
    private $ServicetemplatesTable;

    /**
     * @var ServicetemplategroupsTable
     */
    private $ServicetemplategroupsTable;

    /**
     * @var WizardAssignmentsTable
     */
    private $WizardAssignmentsTable;

    /**
     * @var array
     */
    private $mapping = [];

    /**
     * TemplateImport constructor.
     * @param CommandsTable $CommandsTable
     * @param ServicetemplatesTable $ServicetemplatesTable
     * @param ServicetemplategroupsTable $ServicetemplategroupsTable
     * @param WizardAssignmentsTable $WizardAssignmentsTable
     */
    public function __construct(CommandsTable $CommandsTable, ServicetemplatesTable $ServicetemplatesTable, ServicetemplategroupsTable $ServicetemplategroupsTable, WizardAssignmentsTable $WizardAssignmentsTable) {
        $this->CommandsTable = $CommandsTable;
        $this->ServicetemplatesTable = $ServicetemplatesTable;
        $this->ServicetemplategroupsTable = $ServicetemplategroupsTable;
        $this->WizardAssignmentsTable = $WizardAssignmentsTable;
    }


    /**
     * @return bool
     */
    public function import() {
        $data = $this->getData();
        foreach ($data['Commands'] as $command) {
            if (isset($command['uuid']) && !$this->CommandsTable->existsByUuid($command['uuid'])) {
                $entity = $this->CommandsTable->newEntity($command);
                $this->CommandsTable->save($entity);
            }
        }
        $this->mapping['servicetemplates'] = [];

        foreach ($data['Servicetemplates'] as $servicetemplate) {
            if ($this->ServicetemplatesTable->existsByUuid($servicetemplate['uuid'])) {
                $existingServicetemplate = $this->ServicetemplatesTable->getServicetemplateByUuid($servicetemplate['uuid']);
                $this->mapping['servicetemplates'][$servicetemplate['uuid']] = $existingServicetemplate['Servicetemplate']['id'];
                //skip current template if it already exists
                continue;
            }
            if (isset($servicetemplate['uuid']) && !$this->ServicetemplatesTable->existsByUuid($servicetemplate['uuid'])) {
                if (isset($servicetemplate['command_id']) && $this->CommandsTable->existsByUuid($servicetemplate['command_id'])) {
                    $command = $this->CommandsTable->getCommandByUuid($servicetemplate['command_id'], true, false)[0];
                    $servicetemplate['command_id'] = $command['id'];
                    if (!empty($servicetemplate['servicetemplatecommandargumentvalues']) && !empty($command['commandarguments'])) {
                        foreach ($servicetemplate['servicetemplatecommandargumentvalues'] as $templateArgumentKey => $templateArgumentValue) {
                            $servicetemplate['servicetemplatecommandargumentvalues'][$templateArgumentKey] = [
                                'commandargument_id' => $this->getCommandArgumentIdByName($templateArgumentValue['commandargument_id'], $command['commandarguments']),
                                'value'              => $templateArgumentValue['value'],
                            ];
                        }
                    }
                    $entity = $this->ServicetemplatesTable->newEntity($servicetemplate);
                    $this->ServicetemplatesTable->save($entity);
                    $this->mapping['servicetemplates'][$entity->get('uuid')] = $entity->get('id');
                }
            }
        }
        foreach ($data['Servicetemplategroups'] as $servicetemplategroup) {
            if ($this->ServicetemplategroupsTable->existsByUuid($servicetemplategroup['uuid'])) {
                //skip current service template group if its already exists
                continue;
            }
            if (!empty($this->mapping['servicetemplates'])) {
                foreach ($servicetemplategroup['servicetemplates'] as $key => $servicetemplate) {
                    $currIdAsUuid = $servicetemplate['id'];

                    if (isset($this->mapping['servicetemplates'][$currIdAsUuid])) {
                        $servicetemplategroup['servicetemplates']['_ids'][] = $this->mapping['servicetemplates'][$currIdAsUuid];
                    }

                }
            }

            $entity = $this->ServicetemplategroupsTable->newEntity($servicetemplategroup);
            $this->ServicetemplategroupsTable->save($entity);
        }


        if (!empty($data['Wizardassignment'])) {
            foreach ($data['Wizardassignment'] as $wizardassignment) {
                $wizardassignmentEntity['servicetemplates']['_ids'] = [];
                $wizardassignmentEntity['uuid'] = $wizardassignment['uuid'];
                $wizardassignmentEntity['type_id'] = $wizardassignment['type_id'];
                foreach ($wizardassignment['servicetemplates']['_ids'] as $servicetemplateUuid) {
                    $servicetemplate = $this->ServicetemplatesTable->getServicetemplateByUuid($servicetemplateUuid);
                    if (isset($servicetemplate['Servicetemplate']) && isset($servicetemplate['Servicetemplate']['id'])) {
                        $wizardassignmentEntity['servicetemplates']['_ids'][] = $servicetemplate['Servicetemplate']['id'];
                    }
                }
                if (!$this->WizardAssignmentsTable->existsByUuidAndTypeId($wizardassignmentEntity['uuid'], $wizardassignmentEntity['type_id'])) {
                    $entity = $this->WizardAssignmentsTable->newEntity($wizardassignmentEntity);
                    $this->WizardAssignmentsTable->save($entity);
                } else {
                    $existingAssignment = $this->WizardAssignmentsTable->getWizardByUuidForEdit($wizardassignmentEntity['uuid']);
                    foreach (array_diff($wizardassignmentEntity['servicetemplates']['_ids'], $existingAssignment['servicetemplates']['_ids']) as $missingServicetemplateId) {
                        $existingAssignment['servicetemplates']['_ids'][] = $missingServicetemplateId;
                    }
                    $entity = $this->WizardAssignmentsTable->get($existingAssignment['id']);
                    $entity = $this->WizardAssignmentsTable->patchEntity($entity, $existingAssignment);
                    $this->WizardAssignmentsTable->save($entity);
                }
            }
        }
        return true;
    }

    public function getData() {
        return [
            'Commands'              => $this->getCommandsData(),
            'Servicetemplates'      => $this->getServicetemplatesData(),
            'Servicetemplategroups' => $this->getServicetemplategroupsData(),
            'Wizardassignment'      => $this->getWizardAssignmentData()
        ];
    }

    /**
     * @param string $name
     * @param array $commandarguments
     * @return bool|mixed
     */
    public function getCommandArgumentIdByName(string $name, array $commandarguments) {
        foreach ($commandarguments as $commandargument) {
            if (isset($commandargument['name']) && $commandargument['name'] === $name) {
                return $commandargument['id'];
            }
        }
        return false;
    }


    /**
     * @return array
     */
    public function getWizardAssignmentData() {
        $data = [
            [
                'uuid'             => '28b48f3c-5510-49a2-9fa5-00fd66cee4f2d',
                'type_id'          => 'vmware-through-vcenter',
                'servicetemplates' => [
                    '_ids' => [
                        '24712527-fa26-4c7b-8428-3a399b4c46ea',
                        'ff4d94f2-deba-421a-8e46-8c9a6fa1677e',
                        '20284cca-e077-4cae-a050-51c905a909a5',
                        '80084611-da9b-4e0c-8594-4907dff3332f',
                        'e469a958-b470-4aa5-96d7-066db849f5e1',
                        '3d5a5e0e-c006-470b-b4dc-c135903d1d4c',
                        'c2641835-735f-464c-a022-911abe42983f',
                        'c1f9d9e8-40d5-4eaf-800e-3eb323ff5911',
                        '37cd9f11-63df-4e09-b75d-e409a2eb2c67',
                        'ab55634a-344b-485e-9754-08110527881f'
                    ]
                ]
            ],
            [
                'uuid'             => '92add831-ad5b-453c-87e0-96d32d324a99',
                'type_id'          => 'vmware-esx-directly',
                'servicetemplates' => [
                    '_ids' => [
                        'bff9adeb-9d14-4630-bc87-e1fc8c527c3f',
                        '340153eb-dc0e-43af-a366-212bfb300ba4',
                        'f5ebdbb1-04c7-4392-b300-566705fa49b6',
                        '7b62301f-14a6-4a15-beaf-f8f16e9fff24',
                        'b4c4bc2c-ed19-4283-97af-29f3f1cf8eeb',
                        '68bd2af0-8a07-4e3b-86d3-f460e4e02ebd',
                        'b6ffb1fa-dd2b-471e-afb1-cbdeb4d34ef1',
                        '5b1528ff-f2ac-4c78-9671-461501e38750',
                        '48e2f093-65b6-4200-b7e5-981b841e2e27',
                        '8135bb3e-e14a-4a24-a230-1dda1865692e'
                    ]
                ]
            ]
        ];
        return $data;
    }

    /**
     * @return array
     */
    public function getCommandsData() {
        $data = [
            /** Through vCenter  */
            0  => [
                'name'             => 'check_vmware_vcenter_cpu',
                'command_line'     => '$USER1$/check_vmware_esx --select=cpu --subselect=usage --username="$_HOSTUSERNAME$" --password="$_HOSTPASSWORD$" --datacenter="$_HOSTVCENTER$" --host="$HOSTDISPLAYNAME$" --sessionfile=$HOSTNAME$ --warning=$ARG1$ --critical=$ARG2$',
                'command_type'     => '1',
                'human_args'       => null,
                'uuid'             => '6bd398a2-89b0-48e1-adb1-5271d007cd0b',
                'description'      => 'CPU Usage in percentage.',
                'commandarguments' => [
                    0 =>
                        [
                            'name'       => '$ARG1$',
                            'human_name' => 'Warning',
                        ],
                    1 =>
                        [
                            'name'       => '$ARG2$',
                            'human_name' => 'Critical',
                        ],
                ]
            ],
            1  => [
                'name'             => 'check_vmware_vcenter_memory',
                'command_line'     => '$USER1$/check_vmware_esx --select=mem --subselect=usage --username="$_HOSTUSERNAME$" --password="$_HOSTPASSWORD$" --datacenter="$_HOSTVCENTER$" --host="$HOSTDISPLAYNAME$" --sessionfile=$HOSTNAME$ --warning=$ARG1$ --critical=$ARG2$',
                'command_type'     => '1',
                'human_args'       => null,
                'uuid'             => '95694e86-af01-45e0-a85a-3a5ccf1b7ced',
                'description'      => 'All memory information (except overall and no thresholds).',
                'commandarguments' => [
                    0 =>
                        [
                            'name'       => '$ARG1$',
                            'human_name' => 'Warning',
                        ],
                    1 =>
                        [
                            'name'       => '$ARG2$',
                            'human_name' => 'Critical',
                        ],
                ]
            ],
            2  => [
                'name'             => 'check_vmware_vcenter_network',
                'command_line'     => '$USER1$/check_vmware_esx --select=net --username="$_HOSTUSERNAME$" --password="$_HOSTPASSWORD$" --datacenter="$_HOSTVCENTER$" --host="$HOSTDISPLAYNAME$" --sessionfile=$HOSTNAME$',
                'command_type'     => '1',
                'human_args'       => null,
                'uuid'             => '7de728ee-eae9-4d40-96c7-9164d0bc73a1',
                'description'      => 'Shows network information.',
                'commandarguments' => []
            ],
            3  => [
                'name'             => 'check_vmware_vcenter_volumes',
                'command_line'     => '$USER1$/check_vmware_esx --select=volumes --usedspace --username="$_HOSTUSERNAME$" --password="$_HOSTPASSWORD$" --datacenter="$_HOSTVCENTER$" --host="$HOSTDISPLAYNAME$" --sessionfile=$HOSTNAME$ --warning=$ARG1$ --critical=$ARG2$',
                'command_type'     => '1',
                'human_args'       => null,
                'uuid'             => '10f34403-f8c6-4e13-9c09-1bd1aec960fa',
                'description'      => 'Shows all datastore volumes information.',
                'commandarguments' => [
                    0 =>
                        [
                            'name'       => '$ARG1$',
                            'human_name' => 'Warning',
                        ],
                    1 =>
                        [
                            'name'       => '$ARG2$',
                            'human_name' => 'Critical',
                        ],
                ]
            ],
            4  => [
                'name'             => 'check_vmware_vcenter_disk_io',
                'command_line'     => '$USER1$/check_vmware_esx --select=io --username="$_HOSTUSERNAME$" --password="$_HOSTPASSWORD$" --datacenter="$_HOSTVCENTER$" --host="$HOSTDISPLAYNAME$" --sessionfile=$HOSTNAME$',
                'command_type'     => '1',
                'human_args'       => null,
                'uuid'             => '21835861-64d2-4e8d-86ab-91972e04d7d6',
                'description'      => 'Shows all disk io info. Without subselect no thresholds can be given. All I/O values are aggregated from historical intervals over the past 24 hours with a 5 minute sample rate.',
                'commandarguments' => []
            ],
            5  => [
                'name'             => 'check_vmware_vcenter_services',
                'command_line'     => '$USER1$/check_vmware_esx --select=service --username="$_HOSTUSERNAME$" --password="$_HOSTPASSWORD$" --datacenter="$_HOSTVCENTER$" --host="$HOSTDISPLAYNAME$" --sessionfile=$HOSTNAME$',
                'command_type'     => '1',
                'human_args'       => null,
                'uuid'             => '1fed3456-365f-4349-ba9a-f3f5bedc05ee',
                'description'      => 'Shows host service information.',
                'commandarguments' => []
            ],
            6  => [
                'name'             => 'check_vmware_vcenter_health',
                'command_line'     => '$USER1$/check_vmware_esx --select=runtime --subselect=health --username="$_HOSTUSERNAME$" --password="$_HOSTPASSWORD$" --datacenter="$_HOSTVCENTER$" --host="$HOSTDISPLAYNAME$" --sessionfile=$HOSTNAME$',
                'command_type'     => '1',
                'human_args'       => null,
                'uuid'             => 'd78d6433-da5d-4ae9-b8c8-6a7486473ab8',
                'description'      => 'Checks cpu/storage/memory/sensor status.',
                'commandarguments' => []
            ],
            7  => [
                'name'             => 'check_vmware_vcenter_local_storage_health',
                'command_line'     => '$USER1$/check_vmware_esx --select=runtime --subselect=storagehealth --username="$_HOSTUSERNAME$" --password="$_HOSTPASSWORD$" --datacenter="$_HOSTVCENTER$" --host="$HOSTDISPLAYNAME$" --sessionfile=$HOSTNAME$',
                'command_type'     => '1',
                'human_args'       => null,
                'uuid'             => 'e21ad5ce-a929-4930-bbbf-6eb4cb410b0a',
                'description'      => 'Local(!) storage status check.',
                'commandarguments' => []
            ],
            8  => [
                'name'             => 'check_vmware_vcenter_temp',
                'command_line'     => '$USER1$/check_vmware_esx --select=runtime --subselect=temp --username="$_HOSTUSERNAME$" --password="$_HOSTPASSWORD$" --datacenter="$_HOSTVCENTER$" --host="$HOSTDISPLAYNAME$" --sessionfile=$HOSTNAME$',
                'command_type'     => '1',
                'human_args'       => null,
                'uuid'             => '9299ca4d-fa50-47f2-90a7-0176f82a7fe9',
                'description'      => 'Lists all temperature sensors.',
                'commandarguments' => []
            ],
            9  => [
                'name'             => 'check_vmware_vcenter_storage',
                'command_line'     => '$USER1$/check_vmware_esx --select=storage --username="$_HOSTUSERNAME$" --password="$_HOSTPASSWORD$" --datacenter="$_HOSTVCENTER$" --host="$HOSTDISPLAYNAME$" --sessionfile=$HOSTNAME$',
                'command_type'     => '1',
                'human_args'       => null,
                'uuid'             => '9c328224-ad08-4b4e-8406-159efbc2631e',
                'description'      => 'Shows Host storage information.',
                'commandarguments' => []
            ],
            /** ESX directly  */
            10 => [
                'name'             => 'check_vmware_esx_cpu',
                'command_line'     => '$USER1$/check_vmware_esx --select=cpu --subselect=usage --username="$_HOSTUSERNAME$" --password="$_HOSTPASSWORD$" --host=$HOSTADDRESS$ --sessionfile=$HOSTNAME$ --warning=$ARG1$ --critical=$ARG2$',
                'command_type'     => '1',
                'human_args'       => null,
                'uuid'             => '84cd8225-fdd8-4891-9e06-d8e53d315720',
                'description'      => 'CPU Usage in percentage.',
                'commandarguments' => [
                    0 =>
                        [
                            'name'       => '$ARG1$',
                            'human_name' => 'Warning',
                        ],
                    1 =>
                        [
                            'name'       => '$ARG2$',
                            'human_name' => 'Critical',
                        ],
                ]
            ],
            11 => [
                'name'             => 'check_vmware_esx_memory',
                'command_line'     => '$USER1$/check_vmware_esx --select=mem --subselect=usage --username="$_HOSTUSERNAME$" --password="$_HOSTPASSWORD$" --host=$HOSTADDRESS$ --sessionfile=$HOSTNAME$ --warning=$ARG1$ --critical=$ARG2$',
                'command_type'     => '1',
                'human_args'       => null,
                'uuid'             => 'f46ad4d5-8034-4a0a-9d11-400e5ee93e52',
                'description'      => 'All memory information (except overall and no thresholds).',
                'commandarguments' => [
                    0 =>
                        [
                            'name'       => '$ARG1$',
                            'human_name' => 'Warning',
                        ],
                    1 =>
                        [
                            'name'       => '$ARG2$',
                            'human_name' => 'Critical',
                        ],
                ]
            ],
            12 => [
                'name'             => 'check_vmware_esx_network',
                'command_line'     => '$USER1$/check_vmware_esx --select=net --username="$_HOSTUSERNAME$" --password="$_HOSTPASSWORD$" --host=$HOSTADDRESS$ --sessionfile=$HOSTNAME$',
                'command_type'     => '1',
                'human_args'       => null,
                'uuid'             => '90b37b0e-518c-448f-9046-c5c2c521b2b0',
                'description'      => 'Shows network information.',
                'commandarguments' => [],
            ],
            13 => [
                'name'             => 'check_vmware_esx_volumes',
                'command_line'     => '$USER1$/check_vmware_esx --select=volumes --usedspace --username="$_HOSTUSERNAME$" --password="$_HOSTPASSWORD$" --host=$HOSTADDRESS$ --sessionfile=$HOSTNAME$ --warning=$ARG1$ --critical=$ARG2$',
                'command_type'     => '1',
                'human_args'       => null,
                'uuid'             => 'f1b02a77-1a58-4439-ac1c-e4ff66426fc4',
                'description'      => 'Shows all datastore volumes information.',
                'commandarguments' => [
                    0 =>
                        [
                            'name'       => '$ARG1$',
                            'human_name' => 'Warning',
                        ],
                    1 =>
                        [
                            'name'       => '$ARG2$',
                            'human_name' => 'Critical',
                        ],
                ]
            ],
            14 => [
                'name'             => 'check_vmware_esx_disk_io',
                'command_line'     => '$USER1$/check_vmware_esx --select=io --username="$_HOSTUSERNAME$" --password="$_HOSTPASSWORD$" --host=$HOSTADDRESS$ --sessionfile=$HOSTNAME$',
                'command_type'     => '1',
                'human_args'       => null,
                'uuid'             => '7ce4ec2e-6503-42d2-bb55-482a5b8bef74',
                'description'      => 'Shows all disk io info. Without subselect no thresholds can be given. All I/O values are aggregated from historical intervals over the past 24 hours with a 5 minute sample rate.',
                'commandarguments' => []
            ],
            15 => [
                'name'             => 'check_vmware_esx_services',
                'command_line'     => '$USER1$/check_vmware_esx --select=service --username="$_HOSTUSERNAME$" --password="$_HOSTPASSWORD$" --host=$HOSTADDRESS$ --sessionfile=$HOSTNAME$',
                'command_type'     => '1',
                'human_args'       => null,
                'uuid'             => '4c7fde2c-61da-45ba-95b0-4cd6a7310c62',
                'description'      => 'Shows host service information.',
                'commandarguments' => []
            ],
            16 => [
                'name'             => 'check_vmware_esx_health',
                'command_line'     => '$USER1$/check_vmware_esx --select=runtime --subselect=health --username="$_HOSTUSERNAME$" --password="$_HOSTPASSWORD$" --host=$HOSTADDRESS$ --sessionfile=$HOSTNAME$',
                'command_type'     => '1',
                'human_args'       => null,
                'uuid'             => '4efd4de4-e86b-4deb-92a8-2c608664be60',
                'description'      => 'Checks cpu/storage/memory/sensor status.',
                'commandarguments' => []
            ],
            17 => [
                'name'             => 'check_vmware_esx_local_storage_health',
                'command_line'     => '$USER1$/check_vmware_esx --select=runtime --subselect=storagehealth --username="$_HOSTUSERNAME$" --password="$_HOSTPASSWORD$" --host=$HOSTADDRESS$ --sessionfile=$HOSTNAME$',
                'command_type'     => '1',
                'human_args'       => null,
                'uuid'             => '3fb145fb-1256-459f-bfa8-53867225afa8',
                'description'      => 'Local(!) storage status check.',
                'commandarguments' => []
            ],
            18 => [
                'name'             => 'check_vmware_esx_temp',
                'command_line'     => '$USER1$/check_vmware_esx --select=runtime --subselect=temp --username="$_HOSTUSERNAME$" --password="$_HOSTPASSWORD$" --host=$HOSTADDRESS$ --sessionfile=$HOSTNAME$',
                'command_type'     => '1',
                'human_args'       => null,
                'uuid'             => 'a9544fb7-c20b-4064-ba18-9dc1369fafda',
                'description'      => 'Lists all temperature sensors.',
                'commandarguments' => []
            ],
            19 => [
                'name'             => 'check_vmware_esx_storage',
                'command_line'     => '$USER1$/check_vmware_esx --select=storage --username="$_HOSTUSERNAME$" --password="$_HOSTPASSWORD$" --host=$HOSTADDRESS$ --sessionfile=$HOSTNAME$',
                'command_type'     => '1',
                'human_args'       => null,
                'uuid'             => '9babe57f-1fa4-44dd-9850-fdc996d25046',
                'description'      => 'Shows Host storage information.',
                'commandarguments' => []
            ]
        ];

        return $data;
    }

    /**
     * @return array
     */
    public function getServicetemplatesData() {
        $data = [
            0  =>
                [
                    'uuid'                                      => '24712527-fa26-4c7b-8428-3a399b4c46ea',
                    'template_name'                             => 'VMWARE_VCENTER_CPU',
                    'name'                                      => 'CPU Usage',
                    'container_id'                              => '1',
                    'servicetemplatetype_id'                    => '1',
                    'check_period_id'                           => '1',
                    'notify_period_id'                          => '1',
                    'description'                               => 'CPU Usage in percentage',
                    'command_id'                                => '6bd398a2-89b0-48e1-adb1-5271d007cd0b',
                    'check_command_args'                        => '',
                    'checkcommand_info'                         => '',
                    'eventhandler_command_id'                   => '0',
                    'timeperiod_id'                             => '0',
                    'check_interval'                            => '60',
                    'retry_interval'                            => '60',
                    'max_check_attempts'                        => '3',
                    'first_notification_delay'                  => '0',
                    'notification_interval'                     => '7200',
                    'notify_on_warning'                         => '1',
                    'notify_on_unknown'                         => '0',
                    'notify_on_critical'                        => '1',
                    'notify_on_recovery'                        => '1',
                    'notify_on_flapping'                        => '0',
                    'notify_on_downtime'                        => '0',
                    'flap_detection_enabled'                    => '0',
                    'flap_detection_on_ok'                      => '0',
                    'flap_detection_on_warning'                 => '0',
                    'flap_detection_on_unknown'                 => '0',
                    'flap_detection_on_critical'                => '0',
                    'low_flap_threshold'                        => '0',
                    'high_flap_threshold'                       => '0',
                    'process_performance_data'                  => '1',
                    'freshness_checks_enabled'                  => '0',
                    'freshness_threshold'                       => null,
                    'passive_checks_enabled'                    => '0',
                    'event_handler_enabled'                     => '0',
                    'active_checks_enabled'                     => '1',
                    'retain_status_information'                 => '0',
                    'retain_nonstatus_information'              => '0',
                    'notifications_enabled'                     => '1',
                    'notes'                                     => '',
                    'priority'                                  => '1',
                    'tags'                                      => '',
                    'service_url'                               => '',
                    'is_volatile'                               => '0',
                    'check_freshness'                           => '0',
                    'created'                                   => '2018-09-21 14:38:06',
                    'modified'                                  => '2018-10-17 10:34:43',
                    'servicetemplateeventcommandargumentvalues' =>
                        [
                        ],
                    'servicetemplatecommandargumentvalues'      =>
                        [
                            0 =>
                                [
                                    'commandargument_id' => '$ARG1$',
                                    'value'              => '80%',
                                ],
                            1 =>
                                [
                                    'commandargument_id' => '$ARG2$',
                                    'value'              => '90%',
                                ],
                        ],
                    'customvariables'                           =>
                        [
                        ],
                    'servicegroups'                             =>
                        [
                        ],
                    'contactgroups'                             =>
                        [
                        ],
                    'contacts'                                  =>
                        [
                        ],
                ],
            1  => [
                'uuid'                                      => 'ff4d94f2-deba-421a-8e46-8c9a6fa1677e',
                'template_name'                             => 'VMWARE_VCENTER_MEMORY',
                'name'                                      => 'Memory Usage',
                'container_id'                              => '1',
                'servicetemplatetype_id'                    => '1',
                'check_period_id'                           => '1',
                'notify_period_id'                          => '1',
                'description'                               => 'All memory information(except overall and no thresholds)',
                'command_id'                                => '95694e86-af01-45e0-a85a-3a5ccf1b7ced',
                'check_command_args'                        => '',
                'checkcommand_info'                         => '',
                'eventhandler_command_id'                   => '0',
                'timeperiod_id'                             => '0',
                'check_interval'                            => '60',
                'retry_interval'                            => '60',
                'max_check_attempts'                        => '3',
                'first_notification_delay'                  => '0',
                'notification_interval'                     => '7200',
                'notify_on_warning'                         => '1',
                'notify_on_unknown'                         => '0',
                'notify_on_critical'                        => '1',
                'notify_on_recovery'                        => '1',
                'notify_on_flapping'                        => '0',
                'notify_on_downtime'                        => '0',
                'flap_detection_enabled'                    => '0',
                'flap_detection_on_ok'                      => '0',
                'flap_detection_on_warning'                 => '0',
                'flap_detection_on_unknown'                 => '0',
                'flap_detection_on_critical'                => '0',
                'low_flap_threshold'                        => '0',
                'high_flap_threshold'                       => '0',
                'process_performance_data'                  => '1',
                'freshness_checks_enabled'                  => '0',
                'freshness_threshold'                       => null,
                'passive_checks_enabled'                    => '0',
                'event_handler_enabled'                     => '0',
                'active_checks_enabled'                     => '1',
                'retain_status_information'                 => '0',
                'retain_nonstatus_information'              => '0',
                'notifications_enabled'                     => '1',
                'notes'                                     => '',
                'priority'                                  => '1',
                'tags'                                      => '',
                'service_url'                               => '',
                'is_volatile'                               => '0',
                'check_freshness'                           => '0',
                'created'                                   => '2018-09-21 14:38:06',
                'modified'                                  => '2018-10-17 10:34:43',
                'servicetemplateeventcommandargumentvalues' =>
                    [
                    ],
                'servicetemplatecommandargumentvalues'      =>
                    [
                        0 =>
                            [
                                'commandargument_id' => '$ARG1$',
                                'value'              => '90%',
                            ],
                        1 =>
                            [
                                'commandargument_id' => '$ARG2$',
                                'value'              => '95%',
                            ],
                    ],
                'customvariables'                           =>
                    [
                    ],
                'servicegroups'                             =>
                    [
                    ],
                'contactgroups'                             =>
                    [
                    ],
                'contacts'                                  =>
                    [
                    ],
            ],
            2  => [
                'uuid'                                      => '20284cca-e077-4cae-a050-51c905a909a5',
                'template_name'                             => 'VMWARE_VCENTER_NET',
                'name'                                      => 'Network Usage',
                'container_id'                              => '1',
                'servicetemplatetype_id'                    => '1',
                'check_period_id'                           => '1',
                'notify_period_id'                          => '1',
                'description'                               => 'Shows network information',
                'command_id'                                => '7de728ee-eae9-4d40-96c7-9164d0bc73a1',
                'check_command_args'                        => '',
                'checkcommand_info'                         => '',
                'eventhandler_command_id'                   => '0',
                'timeperiod_id'                             => '0',
                'check_interval'                            => '60',
                'retry_interval'                            => '60',
                'max_check_attempts'                        => '3',
                'first_notification_delay'                  => '0',
                'notification_interval'                     => '7200',
                'notify_on_warning'                         => '1',
                'notify_on_unknown'                         => '0',
                'notify_on_critical'                        => '1',
                'notify_on_recovery'                        => '1',
                'notify_on_flapping'                        => '0',
                'notify_on_downtime'                        => '0',
                'flap_detection_enabled'                    => '0',
                'flap_detection_on_ok'                      => '0',
                'flap_detection_on_warning'                 => '0',
                'flap_detection_on_unknown'                 => '0',
                'flap_detection_on_critical'                => '0',
                'low_flap_threshold'                        => '0',
                'high_flap_threshold'                       => '0',
                'process_performance_data'                  => '1',
                'freshness_checks_enabled'                  => '0',
                'freshness_threshold'                       => null,
                'passive_checks_enabled'                    => '0',
                'event_handler_enabled'                     => '0',
                'active_checks_enabled'                     => '1',
                'retain_status_information'                 => '0',
                'retain_nonstatus_information'              => '0',
                'notifications_enabled'                     => '1',
                'notes'                                     => '',
                'priority'                                  => '1',
                'tags'                                      => '',
                'service_url'                               => '',
                'is_volatile'                               => '0',
                'check_freshness'                           => '0',
                'created'                                   => '2018-09-21 14:38:06',
                'modified'                                  => '2018-10-17 10:34:43',
                'servicetemplateeventcommandargumentvalues' =>
                    [
                    ],
                'servicetemplatecommandargumentvalues'      =>
                    [
                    ],
                'customvariables'                           =>
                    [
                    ],
                'servicegroups'                             =>
                    [
                    ],
                'contactgroups'                             =>
                    [
                    ],
                'contacts'                                  =>
                    [
                    ],
            ],
            3  => [
                'uuid'                                      => '80084611-da9b-4e0c-8594-4907dff3332f',
                'template_name'                             => 'VMWARE_VCENTER_VOLUMES',
                'name'                                      => 'Volumes',
                'container_id'                              => '1',
                'servicetemplatetype_id'                    => '1',
                'check_period_id'                           => '1',
                'notify_period_id'                          => '1',
                'description'                               => 'Shows all datastore volumes info',
                'command_id'                                => '10f34403-f8c6-4e13-9c09-1bd1aec960fa',
                'check_command_args'                        => '',
                'checkcommand_info'                         => '',
                'eventhandler_command_id'                   => '0',
                'timeperiod_id'                             => '0',
                'check_interval'                            => '60',
                'retry_interval'                            => '60',
                'max_check_attempts'                        => '3',
                'first_notification_delay'                  => '0',
                'notification_interval'                     => '7200',
                'notify_on_warning'                         => '1',
                'notify_on_unknown'                         => '0',
                'notify_on_critical'                        => '1',
                'notify_on_recovery'                        => '1',
                'notify_on_flapping'                        => '0',
                'notify_on_downtime'                        => '0',
                'flap_detection_enabled'                    => '0',
                'flap_detection_on_ok'                      => '0',
                'flap_detection_on_warning'                 => '0',
                'flap_detection_on_unknown'                 => '0',
                'flap_detection_on_critical'                => '0',
                'low_flap_threshold'                        => '0',
                'high_flap_threshold'                       => '0',
                'process_performance_data'                  => '1',
                'freshness_checks_enabled'                  => '0',
                'freshness_threshold'                       => null,
                'passive_checks_enabled'                    => '0',
                'event_handler_enabled'                     => '0',
                'active_checks_enabled'                     => '1',
                'retain_status_information'                 => '0',
                'retain_nonstatus_information'              => '0',
                'notifications_enabled'                     => '1',
                'notes'                                     => '',
                'priority'                                  => '1',
                'tags'                                      => '',
                'service_url'                               => '',
                'is_volatile'                               => '0',
                'check_freshness'                           => '0',
                'created'                                   => '2018-09-21 14:38:06',
                'modified'                                  => '2018-10-17 10:34:43',
                'servicetemplateeventcommandargumentvalues' =>
                    [
                    ],
                'servicetemplatecommandargumentvalues'      =>
                    [
                        0 =>
                            [
                                'commandargument_id' => '$ARG1$',
                                'value'              => '90%',
                            ],
                        1 =>
                            [
                                'commandargument_id' => '$ARG2$',
                                'value'              => '95%',
                            ],
                    ],
                'customvariables'                           =>
                    [
                    ],
                'servicegroups'                             =>
                    [
                    ],
                'contactgroups'                             =>
                    [
                    ],
                'contacts'                                  =>
                    [
                    ],
            ],
            4  => [
                'uuid'                                      => 'e469a958-b470-4aa5-96d7-066db849f5e1',
                'template_name'                             => 'VMWARE_VCENTER_DISK_IO',
                'name'                                      => 'Disk IO',
                'container_id'                              => '1',
                'servicetemplatetype_id'                    => '1',
                'check_period_id'                           => '1',
                'notify_period_id'                          => '1',
                'description'                               => 'Shows all disk io information',
                'command_id'                                => '21835861-64d2-4e8d-86ab-91972e04d7d6',
                'check_command_args'                        => '',
                'checkcommand_info'                         => '',
                'eventhandler_command_id'                   => '0',
                'timeperiod_id'                             => '0',
                'check_interval'                            => '60',
                'retry_interval'                            => '60',
                'max_check_attempts'                        => '3',
                'first_notification_delay'                  => '0',
                'notification_interval'                     => '7200',
                'notify_on_warning'                         => '1',
                'notify_on_unknown'                         => '0',
                'notify_on_critical'                        => '1',
                'notify_on_recovery'                        => '1',
                'notify_on_flapping'                        => '0',
                'notify_on_downtime'                        => '0',
                'flap_detection_enabled'                    => '0',
                'flap_detection_on_ok'                      => '0',
                'flap_detection_on_warning'                 => '0',
                'flap_detection_on_unknown'                 => '0',
                'flap_detection_on_critical'                => '0',
                'low_flap_threshold'                        => '0',
                'high_flap_threshold'                       => '0',
                'process_performance_data'                  => '1',
                'freshness_checks_enabled'                  => '0',
                'freshness_threshold'                       => null,
                'passive_checks_enabled'                    => '0',
                'event_handler_enabled'                     => '0',
                'active_checks_enabled'                     => '1',
                'retain_status_information'                 => '0',
                'retain_nonstatus_information'              => '0',
                'notifications_enabled'                     => '1',
                'notes'                                     => '',
                'priority'                                  => '1',
                'tags'                                      => '',
                'service_url'                               => '',
                'is_volatile'                               => '0',
                'check_freshness'                           => '0',
                'created'                                   => '2018-09-21 14:38:06',
                'modified'                                  => '2018-10-17 10:34:43',
                'servicetemplateeventcommandargumentvalues' =>
                    [
                    ],
                'servicetemplatecommandargumentvalues'      =>
                    [
                    ],
                'customvariables'                           =>
                    [
                    ],
                'servicegroups'                             =>
                    [
                    ],
                'contactgroups'                             =>
                    [
                    ],
                'contacts'                                  =>
                    [
                    ],
            ],
            5  => [
                'uuid'                                      => '3d5a5e0e-c006-470b-b4dc-c135903d1d4c',
                'template_name'                             => 'VMWARE_VCENTER_SERVICES',
                'name'                                      => 'Services',
                'container_id'                              => '1',
                'servicetemplatetype_id'                    => '1',
                'check_period_id'                           => '1',
                'notify_period_id'                          => '1',
                'description'                               => 'Shows host service info',
                'command_id'                                => '1fed3456-365f-4349-ba9a-f3f5bedc05ee',
                'check_command_args'                        => '',
                'checkcommand_info'                         => '',
                'eventhandler_command_id'                   => '0',
                'timeperiod_id'                             => '0',
                'check_interval'                            => '60',
                'retry_interval'                            => '60',
                'max_check_attempts'                        => '3',
                'first_notification_delay'                  => '0',
                'notification_interval'                     => '7200',
                'notify_on_warning'                         => '1',
                'notify_on_unknown'                         => '0',
                'notify_on_critical'                        => '1',
                'notify_on_recovery'                        => '1',
                'notify_on_flapping'                        => '0',
                'notify_on_downtime'                        => '0',
                'flap_detection_enabled'                    => '0',
                'flap_detection_on_ok'                      => '0',
                'flap_detection_on_warning'                 => '0',
                'flap_detection_on_unknown'                 => '0',
                'flap_detection_on_critical'                => '0',
                'low_flap_threshold'                        => '0',
                'high_flap_threshold'                       => '0',
                'process_performance_data'                  => '1',
                'freshness_checks_enabled'                  => '0',
                'freshness_threshold'                       => null,
                'passive_checks_enabled'                    => '0',
                'event_handler_enabled'                     => '0',
                'active_checks_enabled'                     => '1',
                'retain_status_information'                 => '0',
                'retain_nonstatus_information'              => '0',
                'notifications_enabled'                     => '1',
                'notes'                                     => '',
                'priority'                                  => '1',
                'tags'                                      => '',
                'service_url'                               => '',
                'is_volatile'                               => '0',
                'check_freshness'                           => '0',
                'created'                                   => '2018-09-21 14:38:06',
                'modified'                                  => '2018-10-17 10:34:43',
                'servicetemplateeventcommandargumentvalues' =>
                    [
                    ],
                'servicetemplatecommandargumentvalues'      =>
                    [
                    ],
                'customvariables'                           =>
                    [
                    ],
                'servicegroups'                             =>
                    [
                    ],
                'contactgroups'                             =>
                    [
                    ],
                'contacts'                                  =>
                    [
                    ],
            ],
            6  => [
                'uuid'                                      => 'c2641835-735f-464c-a022-911abe42983f',
                'template_name'                             => 'VMWARE_VCENTER_HEALTH',
                'name'                                      => 'Health',
                'container_id'                              => '1',
                'servicetemplatetype_id'                    => '1',
                'check_period_id'                           => '1',
                'notify_period_id'                          => '1',
                'description'                               => 'Checks cpu/storage/memory/sensor status',
                'command_id'                                => 'd78d6433-da5d-4ae9-b8c8-6a7486473ab8',
                'check_command_args'                        => '',
                'checkcommand_info'                         => '',
                'eventhandler_command_id'                   => '0',
                'timeperiod_id'                             => '0',
                'check_interval'                            => '60',
                'retry_interval'                            => '60',
                'max_check_attempts'                        => '3',
                'first_notification_delay'                  => '0',
                'notification_interval'                     => '7200',
                'notify_on_warning'                         => '1',
                'notify_on_unknown'                         => '0',
                'notify_on_critical'                        => '1',
                'notify_on_recovery'                        => '1',
                'notify_on_flapping'                        => '0',
                'notify_on_downtime'                        => '0',
                'flap_detection_enabled'                    => '0',
                'flap_detection_on_ok'                      => '0',
                'flap_detection_on_warning'                 => '0',
                'flap_detection_on_unknown'                 => '0',
                'flap_detection_on_critical'                => '0',
                'low_flap_threshold'                        => '0',
                'high_flap_threshold'                       => '0',
                'process_performance_data'                  => '1',
                'freshness_checks_enabled'                  => '0',
                'freshness_threshold'                       => null,
                'passive_checks_enabled'                    => '0',
                'event_handler_enabled'                     => '0',
                'active_checks_enabled'                     => '1',
                'retain_status_information'                 => '0',
                'retain_nonstatus_information'              => '0',
                'notifications_enabled'                     => '1',
                'notes'                                     => '',
                'priority'                                  => '1',
                'tags'                                      => '',
                'service_url'                               => '',
                'is_volatile'                               => '0',
                'check_freshness'                           => '0',
                'created'                                   => '2018-09-21 14:38:06',
                'modified'                                  => '2018-10-17 10:34:43',
                'servicetemplateeventcommandargumentvalues' =>
                    [
                    ],
                'servicetemplatecommandargumentvalues'      =>
                    [
                    ],
                'customvariables'                           =>
                    [
                    ],
                'servicegroups'                             =>
                    [
                    ],
                'contactgroups'                             =>
                    [
                    ],
                'contacts'                                  =>
                    [
                    ],
            ],
            7  => [
                'uuid'                                      => 'c1f9d9e8-40d5-4eaf-800e-3eb323ff5911',
                'template_name'                             => 'VMWARE_VCENTER_LOCAL_STORAGE_HEALTH',
                'name'                                      => 'Local storage health',
                'container_id'                              => '1',
                'servicetemplatetype_id'                    => '1',
                'check_period_id'                           => '1',
                'notify_period_id'                          => '1',
                'description'                               => 'Local(!) storage status check',
                'command_id'                                => 'e21ad5ce-a929-4930-bbbf-6eb4cb410b0a',
                'check_command_args'                        => '',
                'checkcommand_info'                         => '',
                'eventhandler_command_id'                   => '0',
                'timeperiod_id'                             => '0',
                'check_interval'                            => '60',
                'retry_interval'                            => '60',
                'max_check_attempts'                        => '3',
                'first_notification_delay'                  => '0',
                'notification_interval'                     => '7200',
                'notify_on_warning'                         => '1',
                'notify_on_unknown'                         => '0',
                'notify_on_critical'                        => '1',
                'notify_on_recovery'                        => '1',
                'notify_on_flapping'                        => '0',
                'notify_on_downtime'                        => '0',
                'flap_detection_enabled'                    => '0',
                'flap_detection_on_ok'                      => '0',
                'flap_detection_on_warning'                 => '0',
                'flap_detection_on_unknown'                 => '0',
                'flap_detection_on_critical'                => '0',
                'low_flap_threshold'                        => '0',
                'high_flap_threshold'                       => '0',
                'process_performance_data'                  => '1',
                'freshness_checks_enabled'                  => '0',
                'freshness_threshold'                       => null,
                'passive_checks_enabled'                    => '0',
                'event_handler_enabled'                     => '0',
                'active_checks_enabled'                     => '1',
                'retain_status_information'                 => '0',
                'retain_nonstatus_information'              => '0',
                'notifications_enabled'                     => '1',
                'notes'                                     => '',
                'priority'                                  => '1',
                'tags'                                      => '',
                'service_url'                               => '',
                'is_volatile'                               => '0',
                'check_freshness'                           => '0',
                'created'                                   => '2018-09-21 14:38:06',
                'modified'                                  => '2018-10-17 10:34:43',
                'servicetemplateeventcommandargumentvalues' =>
                    [
                    ],
                'servicetemplatecommandargumentvalues'      =>
                    [
                    ],
                'customvariables'                           =>
                    [
                    ],
                'servicegroups'                             =>
                    [
                    ],
                'contactgroups'                             =>
                    [
                    ],
                'contacts'                                  =>
                    [
                    ],
            ],
            8  => [
                'uuid'                                      => '37cd9f11-63df-4e09-b75d-e409a2eb2c67',
                'template_name'                             => 'VMWARE_VCENTER_TEMP',
                'name'                                      => 'Temp',
                'container_id'                              => '1',
                'servicetemplatetype_id'                    => '1',
                'check_period_id'                           => '1',
                'notify_period_id'                          => '1',
                'description'                               => 'Lists all temperature sensors',
                'command_id'                                => '9299ca4d-fa50-47f2-90a7-0176f82a7fe9',
                'check_command_args'                        => '',
                'checkcommand_info'                         => '',
                'eventhandler_command_id'                   => '0',
                'timeperiod_id'                             => '0',
                'check_interval'                            => '60',
                'retry_interval'                            => '60',
                'max_check_attempts'                        => '3',
                'first_notification_delay'                  => '0',
                'notification_interval'                     => '7200',
                'notify_on_warning'                         => '1',
                'notify_on_unknown'                         => '0',
                'notify_on_critical'                        => '1',
                'notify_on_recovery'                        => '1',
                'notify_on_flapping'                        => '0',
                'notify_on_downtime'                        => '0',
                'flap_detection_enabled'                    => '0',
                'flap_detection_on_ok'                      => '0',
                'flap_detection_on_warning'                 => '0',
                'flap_detection_on_unknown'                 => '0',
                'flap_detection_on_critical'                => '0',
                'low_flap_threshold'                        => '0',
                'high_flap_threshold'                       => '0',
                'process_performance_data'                  => '1',
                'freshness_checks_enabled'                  => '0',
                'freshness_threshold'                       => null,
                'passive_checks_enabled'                    => '0',
                'event_handler_enabled'                     => '0',
                'active_checks_enabled'                     => '1',
                'retain_status_information'                 => '0',
                'retain_nonstatus_information'              => '0',
                'notifications_enabled'                     => '1',
                'notes'                                     => '',
                'priority'                                  => '1',
                'tags'                                      => '',
                'service_url'                               => '',
                'is_volatile'                               => '0',
                'check_freshness'                           => '0',
                'created'                                   => '2018-09-21 14:38:06',
                'modified'                                  => '2018-10-17 10:34:43',
                'servicetemplateeventcommandargumentvalues' =>
                    [
                    ],
                'servicetemplatecommandargumentvalues'      =>
                    [
                    ],
                'customvariables'                           =>
                    [
                    ],
                'servicegroups'                             =>
                    [
                    ],
                'contactgroups'                             =>
                    [
                    ],
                'contacts'                                  =>
                    [
                    ],
            ],
            9  => [
                'uuid'                                      => 'ab55634a-344b-485e-9754-08110527881f',
                'template_name'                             => 'VMWARE_VCENTER_STORAGE',
                'name'                                      => 'Storage',
                'container_id'                              => '1',
                'servicetemplatetype_id'                    => '1',
                'check_period_id'                           => '1',
                'notify_period_id'                          => '1',
                'description'                               => 'Shows host storage info',
                'command_id'                                => '9c328224-ad08-4b4e-8406-159efbc2631e',
                'check_command_args'                        => '',
                'checkcommand_info'                         => '',
                'eventhandler_command_id'                   => '0',
                'timeperiod_id'                             => '0',
                'check_interval'                            => '60',
                'retry_interval'                            => '60',
                'max_check_attempts'                        => '3',
                'first_notification_delay'                  => '0',
                'notification_interval'                     => '7200',
                'notify_on_warning'                         => '1',
                'notify_on_unknown'                         => '0',
                'notify_on_critical'                        => '1',
                'notify_on_recovery'                        => '1',
                'notify_on_flapping'                        => '0',
                'notify_on_downtime'                        => '0',
                'flap_detection_enabled'                    => '0',
                'flap_detection_on_ok'                      => '0',
                'flap_detection_on_warning'                 => '0',
                'flap_detection_on_unknown'                 => '0',
                'flap_detection_on_critical'                => '0',
                'low_flap_threshold'                        => '0',
                'high_flap_threshold'                       => '0',
                'process_performance_data'                  => '1',
                'freshness_checks_enabled'                  => '0',
                'freshness_threshold'                       => null,
                'passive_checks_enabled'                    => '0',
                'event_handler_enabled'                     => '0',
                'active_checks_enabled'                     => '1',
                'retain_status_information'                 => '0',
                'retain_nonstatus_information'              => '0',
                'notifications_enabled'                     => '1',
                'notes'                                     => '',
                'priority'                                  => '1',
                'tags'                                      => '',
                'service_url'                               => '',
                'is_volatile'                               => '0',
                'check_freshness'                           => '0',
                'created'                                   => '2018-09-21 14:38:06',
                'modified'                                  => '2018-10-17 10:34:43',
                'servicetemplateeventcommandargumentvalues' =>
                    [
                    ],
                'servicetemplatecommandargumentvalues'      =>
                    [
                    ],
                'customvariables'                           =>
                    [
                    ],
                'servicegroups'                             =>
                    [
                    ],
                'contactgroups'                             =>
                    [
                    ],
                'contacts'                                  =>
                    [
                    ],
            ],
            10 => [
                'uuid'                                      => 'bff9adeb-9d14-4630-bc87-e1fc8c527c3f',
                'template_name'                             => 'VMWARE_ESX_CPU',
                'name'                                      => 'CPU Usage',
                'container_id'                              => '1',
                'servicetemplatetype_id'                    => '1',
                'check_period_id'                           => '1',
                'notify_period_id'                          => '1',
                'description'                               => 'CPU Usage in percentage',
                'command_id'                                => '84cd8225-fdd8-4891-9e06-d8e53d315720',
                'check_command_args'                        => '',
                'checkcommand_info'                         => '',
                'eventhandler_command_id'                   => '0',
                'timeperiod_id'                             => '0',
                'check_interval'                            => '60',
                'retry_interval'                            => '60',
                'max_check_attempts'                        => '3',
                'first_notification_delay'                  => '0',
                'notification_interval'                     => '7200',
                'notify_on_warning'                         => '1',
                'notify_on_unknown'                         => '0',
                'notify_on_critical'                        => '1',
                'notify_on_recovery'                        => '1',
                'notify_on_flapping'                        => '0',
                'notify_on_downtime'                        => '0',
                'flap_detection_enabled'                    => '0',
                'flap_detection_on_ok'                      => '0',
                'flap_detection_on_warning'                 => '0',
                'flap_detection_on_unknown'                 => '0',
                'flap_detection_on_critical'                => '0',
                'low_flap_threshold'                        => '0',
                'high_flap_threshold'                       => '0',
                'process_performance_data'                  => '1',
                'freshness_checks_enabled'                  => '0',
                'freshness_threshold'                       => null,
                'passive_checks_enabled'                    => '0',
                'event_handler_enabled'                     => '0',
                'active_checks_enabled'                     => '1',
                'retain_status_information'                 => '0',
                'retain_nonstatus_information'              => '0',
                'notifications_enabled'                     => '1',
                'notes'                                     => '',
                'priority'                                  => '1',
                'tags'                                      => '',
                'service_url'                               => '',
                'is_volatile'                               => '0',
                'check_freshness'                           => '0',
                'created'                                   => '2018-09-21 14:38:06',
                'modified'                                  => '2018-10-17 10:34:43',
                'servicetemplateeventcommandargumentvalues' =>
                    [
                    ],
                'servicetemplatecommandargumentvalues'      =>
                    [
                        0 =>
                            [
                                'commandargument_id' => '$ARG1$',
                                'value'              => '80%',
                            ],
                        1 =>
                            [
                                'commandargument_id' => '$ARG2$',
                                'value'              => '90%',
                            ],
                    ],
                'customvariables'                           =>
                    [
                    ],
                'servicegroups'                             =>
                    [
                    ],
                'contactgroups'                             =>
                    [
                    ],
                'contacts'                                  =>
                    [
                    ],
            ],
            11 => [
                'uuid'                                      => '340153eb-dc0e-43af-a366-212bfb300ba4',
                'template_name'                             => 'VMWARE_ESX_MEMORY',
                'name'                                      => 'Memory Usage',
                'container_id'                              => '1',
                'servicetemplatetype_id'                    => '1',
                'check_period_id'                           => '1',
                'notify_period_id'                          => '1',
                'description'                               => 'All memory information(except overall and no thresholds)',
                'command_id'                                => 'f46ad4d5-8034-4a0a-9d11-400e5ee93e52',
                'check_command_args'                        => '',
                'checkcommand_info'                         => '',
                'eventhandler_command_id'                   => '0',
                'timeperiod_id'                             => '0',
                'check_interval'                            => '60',
                'retry_interval'                            => '60',
                'max_check_attempts'                        => '3',
                'first_notification_delay'                  => '0',
                'notification_interval'                     => '7200',
                'notify_on_warning'                         => '1',
                'notify_on_unknown'                         => '0',
                'notify_on_critical'                        => '1',
                'notify_on_recovery'                        => '1',
                'notify_on_flapping'                        => '0',
                'notify_on_downtime'                        => '0',
                'flap_detection_enabled'                    => '0',
                'flap_detection_on_ok'                      => '0',
                'flap_detection_on_warning'                 => '0',
                'flap_detection_on_unknown'                 => '0',
                'flap_detection_on_critical'                => '0',
                'low_flap_threshold'                        => '0',
                'high_flap_threshold'                       => '0',
                'process_performance_data'                  => '1',
                'freshness_checks_enabled'                  => '0',
                'freshness_threshold'                       => null,
                'passive_checks_enabled'                    => '0',
                'event_handler_enabled'                     => '0',
                'active_checks_enabled'                     => '1',
                'retain_status_information'                 => '0',
                'retain_nonstatus_information'              => '0',
                'notifications_enabled'                     => '1',
                'notes'                                     => '',
                'priority'                                  => '1',
                'tags'                                      => '',
                'service_url'                               => '',
                'is_volatile'                               => '0',
                'check_freshness'                           => '0',
                'created'                                   => '2018-09-21 14:38:06',
                'modified'                                  => '2018-10-17 10:34:43',
                'servicetemplateeventcommandargumentvalues' =>
                    [
                    ],
                'servicetemplatecommandargumentvalues'      =>
                    [
                        0 =>
                            [
                                'commandargument_id' => '$ARG1$',
                                'value'              => '90%',
                            ],
                        1 =>
                            [
                                'commandargument_id' => '$ARG2$',
                                'value'              => '95%',
                            ],
                    ],
                'customvariables'                           =>
                    [
                    ],
                'servicegroups'                             =>
                    [
                    ],
                'contactgroups'                             =>
                    [
                    ],
                'contacts'                                  =>
                    [
                    ],
            ],
            12 => [
                'uuid'                                      => 'f5ebdbb1-04c7-4392-b300-566705fa49b6',
                'template_name'                             => 'VMWARE_ESX_NET',
                'name'                                      => 'Network Usage',
                'container_id'                              => '1',
                'servicetemplatetype_id'                    => '1',
                'check_period_id'                           => '1',
                'notify_period_id'                          => '1',
                'description'                               => 'Shows network information',
                'command_id'                                => '90b37b0e-518c-448f-9046-c5c2c521b2b0',
                'check_command_args'                        => '',
                'checkcommand_info'                         => '',
                'eventhandler_command_id'                   => '0',
                'timeperiod_id'                             => '0',
                'check_interval'                            => '60',
                'retry_interval'                            => '60',
                'max_check_attempts'                        => '3',
                'first_notification_delay'                  => '0',
                'notification_interval'                     => '7200',
                'notify_on_warning'                         => '1',
                'notify_on_unknown'                         => '0',
                'notify_on_critical'                        => '1',
                'notify_on_recovery'                        => '1',
                'notify_on_flapping'                        => '0',
                'notify_on_downtime'                        => '0',
                'flap_detection_enabled'                    => '0',
                'flap_detection_on_ok'                      => '0',
                'flap_detection_on_warning'                 => '0',
                'flap_detection_on_unknown'                 => '0',
                'flap_detection_on_critical'                => '0',
                'low_flap_threshold'                        => '0',
                'high_flap_threshold'                       => '0',
                'process_performance_data'                  => '1',
                'freshness_checks_enabled'                  => '0',
                'freshness_threshold'                       => null,
                'passive_checks_enabled'                    => '0',
                'event_handler_enabled'                     => '0',
                'active_checks_enabled'                     => '1',
                'retain_status_information'                 => '0',
                'retain_nonstatus_information'              => '0',
                'notifications_enabled'                     => '1',
                'notes'                                     => '',
                'priority'                                  => '1',
                'tags'                                      => '',
                'service_url'                               => '',
                'is_volatile'                               => '0',
                'check_freshness'                           => '0',
                'created'                                   => '2018-09-21 14:38:06',
                'modified'                                  => '2018-10-17 10:34:43',
                'servicetemplateeventcommandargumentvalues' =>
                    [
                    ],
                'servicetemplatecommandargumentvalues'      =>
                    [
                    ],
                'customvariables'                           =>
                    [
                    ],
                'servicegroups'                             =>
                    [
                    ],
                'contactgroups'                             =>
                    [
                    ],
                'contacts'                                  =>
                    [
                    ],
            ],
            13 => [
                'uuid'                                      => '7b62301f-14a6-4a15-beaf-f8f16e9fff24',
                'template_name'                             => 'VMWARE_ESX_VOLUMES',
                'name'                                      => 'Volumes',
                'container_id'                              => '1',
                'servicetemplatetype_id'                    => '1',
                'check_period_id'                           => '1',
                'notify_period_id'                          => '1',
                'description'                               => 'Shows all datastore volumes info',
                'command_id'                                => 'f1b02a77-1a58-4439-ac1c-e4ff66426fc4',
                'check_command_args'                        => '',
                'checkcommand_info'                         => '',
                'eventhandler_command_id'                   => '0',
                'timeperiod_id'                             => '0',
                'check_interval'                            => '60',
                'retry_interval'                            => '60',
                'max_check_attempts'                        => '3',
                'first_notification_delay'                  => '0',
                'notification_interval'                     => '7200',
                'notify_on_warning'                         => '1',
                'notify_on_unknown'                         => '0',
                'notify_on_critical'                        => '1',
                'notify_on_recovery'                        => '1',
                'notify_on_flapping'                        => '0',
                'notify_on_downtime'                        => '0',
                'flap_detection_enabled'                    => '0',
                'flap_detection_on_ok'                      => '0',
                'flap_detection_on_warning'                 => '0',
                'flap_detection_on_unknown'                 => '0',
                'flap_detection_on_critical'                => '0',
                'low_flap_threshold'                        => '0',
                'high_flap_threshold'                       => '0',
                'process_performance_data'                  => '1',
                'freshness_checks_enabled'                  => '0',
                'freshness_threshold'                       => null,
                'passive_checks_enabled'                    => '0',
                'event_handler_enabled'                     => '0',
                'active_checks_enabled'                     => '1',
                'retain_status_information'                 => '0',
                'retain_nonstatus_information'              => '0',
                'notifications_enabled'                     => '1',
                'notes'                                     => '',
                'priority'                                  => '1',
                'tags'                                      => '',
                'service_url'                               => '',
                'is_volatile'                               => '0',
                'check_freshness'                           => '0',
                'created'                                   => '2018-09-21 14:38:06',
                'modified'                                  => '2018-10-17 10:34:43',
                'servicetemplateeventcommandargumentvalues' =>
                    [
                    ],
                'servicetemplatecommandargumentvalues'      =>
                    [
                        0 =>
                            [
                                'commandargument_id' => '$ARG1$',
                                'value'              => '90%',
                            ],
                        1 =>
                            [
                                'commandargument_id' => '$ARG2$',
                                'value'              => '95%',
                            ],
                    ],
                'customvariables'                           =>
                    [
                    ],
                'servicegroups'                             =>
                    [
                    ],
                'contactgroups'                             =>
                    [
                    ],
                'contacts'                                  =>
                    [
                    ],
            ],
            14 => [
                'uuid'                                      => 'b4c4bc2c-ed19-4283-97af-29f3f1cf8eeb',
                'template_name'                             => 'VMWARE_ESX_DISK_IO',
                'name'                                      => 'Disk IO',
                'container_id'                              => '1',
                'servicetemplatetype_id'                    => '1',
                'check_period_id'                           => '1',
                'notify_period_id'                          => '1',
                'description'                               => 'Shows all disk io information',
                'command_id'                                => '7ce4ec2e-6503-42d2-bb55-482a5b8bef74',
                'check_command_args'                        => '',
                'checkcommand_info'                         => '',
                'eventhandler_command_id'                   => '0',
                'timeperiod_id'                             => '0',
                'check_interval'                            => '60',
                'retry_interval'                            => '60',
                'max_check_attempts'                        => '3',
                'first_notification_delay'                  => '0',
                'notification_interval'                     => '7200',
                'notify_on_warning'                         => '1',
                'notify_on_unknown'                         => '0',
                'notify_on_critical'                        => '1',
                'notify_on_recovery'                        => '1',
                'notify_on_flapping'                        => '0',
                'notify_on_downtime'                        => '0',
                'flap_detection_enabled'                    => '0',
                'flap_detection_on_ok'                      => '0',
                'flap_detection_on_warning'                 => '0',
                'flap_detection_on_unknown'                 => '0',
                'flap_detection_on_critical'                => '0',
                'low_flap_threshold'                        => '0',
                'high_flap_threshold'                       => '0',
                'process_performance_data'                  => '1',
                'freshness_checks_enabled'                  => '0',
                'freshness_threshold'                       => null,
                'passive_checks_enabled'                    => '0',
                'event_handler_enabled'                     => '0',
                'active_checks_enabled'                     => '1',
                'retain_status_information'                 => '0',
                'retain_nonstatus_information'              => '0',
                'notifications_enabled'                     => '1',
                'notes'                                     => '',
                'priority'                                  => '1',
                'tags'                                      => '',
                'service_url'                               => '',
                'is_volatile'                               => '0',
                'check_freshness'                           => '0',
                'created'                                   => '2018-09-21 14:38:06',
                'modified'                                  => '2018-10-17 10:34:43',
                'servicetemplateeventcommandargumentvalues' =>
                    [
                    ],
                'servicetemplatecommandargumentvalues'      =>
                    [
                    ],
                'customvariables'                           =>
                    [
                    ],
                'servicegroups'                             =>
                    [
                    ],
                'contactgroups'                             =>
                    [
                    ],
                'contacts'                                  =>
                    [
                    ],
            ],
            15 => [
                'uuid'                                      => '68bd2af0-8a07-4e3b-86d3-f460e4e02ebd',
                'template_name'                             => 'VMWARE_ESX_SERVICES',
                'name'                                      => 'Services',
                'container_id'                              => '1',
                'servicetemplatetype_id'                    => '1',
                'check_period_id'                           => '1',
                'notify_period_id'                          => '1',
                'description'                               => 'Shows host service info',
                'command_id'                                => '4c7fde2c-61da-45ba-95b0-4cd6a7310c62',
                'check_command_args'                        => '',
                'checkcommand_info'                         => '',
                'eventhandler_command_id'                   => '0',
                'timeperiod_id'                             => '0',
                'check_interval'                            => '60',
                'retry_interval'                            => '60',
                'max_check_attempts'                        => '3',
                'first_notification_delay'                  => '0',
                'notification_interval'                     => '7200',
                'notify_on_warning'                         => '1',
                'notify_on_unknown'                         => '0',
                'notify_on_critical'                        => '1',
                'notify_on_recovery'                        => '1',
                'notify_on_flapping'                        => '0',
                'notify_on_downtime'                        => '0',
                'flap_detection_enabled'                    => '0',
                'flap_detection_on_ok'                      => '0',
                'flap_detection_on_warning'                 => '0',
                'flap_detection_on_unknown'                 => '0',
                'flap_detection_on_critical'                => '0',
                'low_flap_threshold'                        => '0',
                'high_flap_threshold'                       => '0',
                'process_performance_data'                  => '1',
                'freshness_checks_enabled'                  => '0',
                'freshness_threshold'                       => null,
                'passive_checks_enabled'                    => '0',
                'event_handler_enabled'                     => '0',
                'active_checks_enabled'                     => '1',
                'retain_status_information'                 => '0',
                'retain_nonstatus_information'              => '0',
                'notifications_enabled'                     => '1',
                'notes'                                     => '',
                'priority'                                  => '1',
                'tags'                                      => '',
                'service_url'                               => '',
                'is_volatile'                               => '0',
                'check_freshness'                           => '0',
                'created'                                   => '2018-09-21 14:38:06',
                'modified'                                  => '2018-10-17 10:34:43',
                'servicetemplateeventcommandargumentvalues' =>
                    [
                    ],
                'servicetemplatecommandargumentvalues'      =>
                    [
                    ],
                'customvariables'                           =>
                    [
                    ],
                'servicegroups'                             =>
                    [
                    ],
                'contactgroups'                             =>
                    [
                    ],
                'contacts'                                  =>
                    [
                    ],
            ],
            16 => [
                'uuid'                                      => 'b6ffb1fa-dd2b-471e-afb1-cbdeb4d34ef1',
                'template_name'                             => 'VMWARE_ESX_HEALTH',
                'name'                                      => 'Health',
                'container_id'                              => '1',
                'servicetemplatetype_id'                    => '1',
                'check_period_id'                           => '1',
                'notify_period_id'                          => '1',
                'description'                               => 'Checks cpu/storage/memory/sensor status',
                'command_id'                                => '4efd4de4-e86b-4deb-92a8-2c608664be60',
                'check_command_args'                        => '',
                'checkcommand_info'                         => '',
                'eventhandler_command_id'                   => '0',
                'timeperiod_id'                             => '0',
                'check_interval'                            => '60',
                'retry_interval'                            => '60',
                'max_check_attempts'                        => '3',
                'first_notification_delay'                  => '0',
                'notification_interval'                     => '7200',
                'notify_on_warning'                         => '1',
                'notify_on_unknown'                         => '0',
                'notify_on_critical'                        => '1',
                'notify_on_recovery'                        => '1',
                'notify_on_flapping'                        => '0',
                'notify_on_downtime'                        => '0',
                'flap_detection_enabled'                    => '0',
                'flap_detection_on_ok'                      => '0',
                'flap_detection_on_warning'                 => '0',
                'flap_detection_on_unknown'                 => '0',
                'flap_detection_on_critical'                => '0',
                'low_flap_threshold'                        => '0',
                'high_flap_threshold'                       => '0',
                'process_performance_data'                  => '1',
                'freshness_checks_enabled'                  => '0',
                'freshness_threshold'                       => null,
                'passive_checks_enabled'                    => '0',
                'event_handler_enabled'                     => '0',
                'active_checks_enabled'                     => '1',
                'retain_status_information'                 => '0',
                'retain_nonstatus_information'              => '0',
                'notifications_enabled'                     => '1',
                'notes'                                     => '',
                'priority'                                  => '1',
                'tags'                                      => '',
                'service_url'                               => '',
                'is_volatile'                               => '0',
                'check_freshness'                           => '0',
                'created'                                   => '2018-09-21 14:38:06',
                'modified'                                  => '2018-10-17 10:34:43',
                'servicetemplateeventcommandargumentvalues' =>
                    [
                    ],
                'servicetemplatecommandargumentvalues'      =>
                    [
                    ],
                'customvariables'                           =>
                    [
                    ],
                'servicegroups'                             =>
                    [
                    ],
                'contactgroups'                             =>
                    [
                    ],
                'contacts'                                  =>
                    [
                    ],
            ],
            17 => [
                'uuid'                                      => '5b1528ff-f2ac-4c78-9671-461501e38750',
                'template_name'                             => 'VMWARE_ESX_LOCAL_STORAGE_HEALTH',
                'name'                                      => 'Local Storage Health',
                'container_id'                              => '1',
                'servicetemplatetype_id'                    => '1',
                'check_period_id'                           => '1',
                'notify_period_id'                          => '1',
                'description'                               => 'Local(!) storage status check',
                'command_id'                                => '3fb145fb-1256-459f-bfa8-53867225afa8',
                'check_command_args'                        => '',
                'checkcommand_info'                         => '',
                'eventhandler_command_id'                   => '0',
                'timeperiod_id'                             => '0',
                'check_interval'                            => '60',
                'retry_interval'                            => '60',
                'max_check_attempts'                        => '3',
                'first_notification_delay'                  => '0',
                'notification_interval'                     => '7200',
                'notify_on_warning'                         => '1',
                'notify_on_unknown'                         => '0',
                'notify_on_critical'                        => '1',
                'notify_on_recovery'                        => '1',
                'notify_on_flapping'                        => '0',
                'notify_on_downtime'                        => '0',
                'flap_detection_enabled'                    => '0',
                'flap_detection_on_ok'                      => '0',
                'flap_detection_on_warning'                 => '0',
                'flap_detection_on_unknown'                 => '0',
                'flap_detection_on_critical'                => '0',
                'low_flap_threshold'                        => '0',
                'high_flap_threshold'                       => '0',
                'process_performance_data'                  => '1',
                'freshness_checks_enabled'                  => '0',
                'freshness_threshold'                       => null,
                'passive_checks_enabled'                    => '0',
                'event_handler_enabled'                     => '0',
                'active_checks_enabled'                     => '1',
                'retain_status_information'                 => '0',
                'retain_nonstatus_information'              => '0',
                'notifications_enabled'                     => '1',
                'notes'                                     => '',
                'priority'                                  => '1',
                'tags'                                      => '',
                'service_url'                               => '',
                'is_volatile'                               => '0',
                'check_freshness'                           => '0',
                'created'                                   => '2018-09-21 14:38:06',
                'modified'                                  => '2018-10-17 10:34:43',
                'servicetemplateeventcommandargumentvalues' =>
                    [
                    ],
                'servicetemplatecommandargumentvalues'      =>
                    [
                    ],
                'customvariables'                           =>
                    [
                    ],
                'servicegroups'                             =>
                    [
                    ],
                'contactgroups'                             =>
                    [
                    ],
                'contacts'                                  =>
                    [
                    ],
            ],
            18 => [
                'uuid'                                      => '48e2f093-65b6-4200-b7e5-981b841e2e27',
                'template_name'                             => 'VMWARE_ESX_TEMP',
                'name'                                      => 'Temp',
                'container_id'                              => '1',
                'servicetemplatetype_id'                    => '1',
                'check_period_id'                           => '1',
                'notify_period_id'                          => '1',
                'description'                               => 'Lists all temperature sensors',
                'command_id'                                => 'a9544fb7-c20b-4064-ba18-9dc1369fafda',
                'check_command_args'                        => '',
                'checkcommand_info'                         => '',
                'eventhandler_command_id'                   => '0',
                'timeperiod_id'                             => '0',
                'check_interval'                            => '60',
                'retry_interval'                            => '60',
                'max_check_attempts'                        => '3',
                'first_notification_delay'                  => '0',
                'notification_interval'                     => '7200',
                'notify_on_warning'                         => '1',
                'notify_on_unknown'                         => '0',
                'notify_on_critical'                        => '1',
                'notify_on_recovery'                        => '1',
                'notify_on_flapping'                        => '0',
                'notify_on_downtime'                        => '0',
                'flap_detection_enabled'                    => '0',
                'flap_detection_on_ok'                      => '0',
                'flap_detection_on_warning'                 => '0',
                'flap_detection_on_unknown'                 => '0',
                'flap_detection_on_critical'                => '0',
                'low_flap_threshold'                        => '0',
                'high_flap_threshold'                       => '0',
                'process_performance_data'                  => '1',
                'freshness_checks_enabled'                  => '0',
                'freshness_threshold'                       => null,
                'passive_checks_enabled'                    => '0',
                'event_handler_enabled'                     => '0',
                'active_checks_enabled'                     => '1',
                'retain_status_information'                 => '0',
                'retain_nonstatus_information'              => '0',
                'notifications_enabled'                     => '1',
                'notes'                                     => '',
                'priority'                                  => '1',
                'tags'                                      => '',
                'service_url'                               => '',
                'is_volatile'                               => '0',
                'check_freshness'                           => '0',
                'created'                                   => '2018-09-21 14:38:06',
                'modified'                                  => '2018-10-17 10:34:43',
                'servicetemplateeventcommandargumentvalues' =>
                    [
                    ],
                'servicetemplatecommandargumentvalues'      =>
                    [
                    ],
                'customvariables'                           =>
                    [
                    ],
                'servicegroups'                             =>
                    [
                    ],
                'contactgroups'                             =>
                    [
                    ],
                'contacts'                                  =>
                    [
                    ],
            ],
            19 => [
                'uuid'                                      => '8135bb3e-e14a-4a24-a230-1dda1865692e',
                'template_name'                             => 'VMWARE_ESX_STORAGE',
                'name'                                      => 'Storage',
                'container_id'                              => '1',
                'servicetemplatetype_id'                    => '1',
                'check_period_id'                           => '1',
                'notify_period_id'                          => '1',
                'description'                               => 'Shows host storage info',
                'command_id'                                => '9babe57f-1fa4-44dd-9850-fdc996d25046',
                'check_command_args'                        => '',
                'checkcommand_info'                         => '',
                'eventhandler_command_id'                   => '0',
                'timeperiod_id'                             => '0',
                'check_interval'                            => '60',
                'retry_interval'                            => '60',
                'max_check_attempts'                        => '3',
                'first_notification_delay'                  => '0',
                'notification_interval'                     => '7200',
                'notify_on_warning'                         => '1',
                'notify_on_unknown'                         => '0',
                'notify_on_critical'                        => '1',
                'notify_on_recovery'                        => '1',
                'notify_on_flapping'                        => '0',
                'notify_on_downtime'                        => '0',
                'flap_detection_enabled'                    => '0',
                'flap_detection_on_ok'                      => '0',
                'flap_detection_on_warning'                 => '0',
                'flap_detection_on_unknown'                 => '0',
                'flap_detection_on_critical'                => '0',
                'low_flap_threshold'                        => '0',
                'high_flap_threshold'                       => '0',
                'process_performance_data'                  => '1',
                'freshness_checks_enabled'                  => '0',
                'freshness_threshold'                       => null,
                'passive_checks_enabled'                    => '0',
                'event_handler_enabled'                     => '0',
                'active_checks_enabled'                     => '1',
                'retain_status_information'                 => '0',
                'retain_nonstatus_information'              => '0',
                'notifications_enabled'                     => '1',
                'notes'                                     => '',
                'priority'                                  => '1',
                'tags'                                      => '',
                'service_url'                               => '',
                'is_volatile'                               => '0',
                'check_freshness'                           => '0',
                'created'                                   => '2018-09-21 14:38:06',
                'modified'                                  => '2018-10-17 10:34:43',
                'servicetemplateeventcommandargumentvalues' =>
                    [
                    ],
                'servicetemplatecommandargumentvalues'      =>
                    [
                    ],
                'customvariables'                           =>
                    [
                    ],
                'servicegroups'                             =>
                    [
                    ],
                'contactgroups'                             =>
                    [
                    ],
                'contacts'                                  =>
                    [
                    ],
            ],
        ];
        return $data;
    }

    public function getServicetemplategroupsData() {
        $data = [
            0 =>
                [
                    'uuid'             => 'a5aec3fd-f23e-4f66-999f-288294079ebf',
                    'description'      => 'Check everything regarding VMware. vCenter, virtual machines...',
                    'servicetemplates' =>
                        [
                            0 =>
                                [
                                    'id'   => '24712527-fa26-4c7b-8428-3a399b4c46ea',
                                    'uuid' => '24712527-fa26-4c7b-8428-3a399b4c46ea',
                                ],
                            1 =>
                                [
                                    'id'   => 'ff4d94f2-deba-421a-8e46-8c9a6fa1677e',
                                    'uuid' => 'ff4d94f2-deba-421a-8e46-8c9a6fa1677e',
                                ],
                            2 =>
                                [
                                    'id'   => '20284cca-e077-4cae-a050-51c905a909a5',
                                    'uuid' => '20284cca-e077-4cae-a050-51c905a909a5',
                                ],
                            3 =>
                                [
                                    'id'   => '80084611-da9b-4e0c-8594-4907dff3332f',
                                    'uuid' => '80084611-da9b-4e0c-8594-4907dff3332f',
                                ],
                            4 =>
                                [
                                    'id'   => 'e469a958-b470-4aa5-96d7-066db849f5e1',
                                    'uuid' => 'e469a958-b470-4aa5-96d7-066db849f5e1',
                                ],
                            5 =>
                                [
                                    'id'   => '3d5a5e0e-c006-470b-b4dc-c135903d1d4c',
                                    'uuid' => '3d5a5e0e-c006-470b-b4dc-c135903d1d4c',
                                ],
                            6 =>
                                [
                                    'id'   => 'c2641835-735f-464c-a022-911abe42983f',
                                    'uuid' => 'c2641835-735f-464c-a022-911abe42983f',
                                ],
                            7 =>
                                [
                                    'id'   => 'c1f9d9e8-40d5-4eaf-800e-3eb323ff5911',
                                    'uuid' => 'c1f9d9e8-40d5-4eaf-800e-3eb323ff5911',
                                ],
                            8 =>
                                [
                                    'id'   => '37cd9f11-63df-4e09-b75d-e409a2eb2c67',
                                    'uuid' => '37cd9f11-63df-4e09-b75d-e409a2eb2c67',
                                ],
                            9 =>
                                [
                                    'id'   => 'ab55634a-344b-485e-9754-08110527881f',
                                    'uuid' => 'ab55634a-344b-485e-9754-08110527881f',
                                ]
                        ],
                    'container'        =>
                        [
                            'name'             => 'VMware Basic Monitoring (Through vCenter)',
                            'parent_id'        => 1,
                            'containertype_id' => '9',
                        ]
                ],
            1 =>
                [
                    'uuid'             => '6e40bc6c-161f-4e3c-ba82-a8b5df8ebe23',
                    'description'      => 'Check everything regarding VMware. ESX Hosts, virtual machines...',
                    'servicetemplates' =>
                        [
                            0 =>
                                [
                                    'id'   => 'bff9adeb-9d14-4630-bc87-e1fc8c527c3f',
                                    'uuid' => 'bff9adeb-9d14-4630-bc87-e1fc8c527c3f',
                                ],
                            1 =>
                                [
                                    'id'   => '340153eb-dc0e-43af-a366-212bfb300ba4',
                                    'uuid' => '340153eb-dc0e-43af-a366-212bfb300ba4',
                                ],
                            2 =>
                                [
                                    'id'   => 'f5ebdbb1-04c7-4392-b300-566705fa49b6',
                                    'uuid' => 'f5ebdbb1-04c7-4392-b300-566705fa49b6',
                                ],
                            3 =>
                                [
                                    'id'   => '7b62301f-14a6-4a15-beaf-f8f16e9fff24',
                                    'uuid' => '7b62301f-14a6-4a15-beaf-f8f16e9fff24',
                                ],
                            4 =>
                                [
                                    'id'   => 'b4c4bc2c-ed19-4283-97af-29f3f1cf8eeb',
                                    'uuid' => 'b4c4bc2c-ed19-4283-97af-29f3f1cf8eeb',
                                ],
                            5 =>
                                [
                                    'id'   => '68bd2af0-8a07-4e3b-86d3-f460e4e02ebd',
                                    'uuid' => '68bd2af0-8a07-4e3b-86d3-f460e4e02ebd',
                                ],
                            6 =>
                                [
                                    'id'   => 'b6ffb1fa-dd2b-471e-afb1-cbdeb4d34ef1',
                                    'uuid' => 'b6ffb1fa-dd2b-471e-afb1-cbdeb4d34ef1',
                                ],
                            7 =>
                                [
                                    'id'   => '5b1528ff-f2ac-4c78-9671-461501e38750',
                                    'uuid' => '5b1528ff-f2ac-4c78-9671-461501e38750',
                                ],
                            8 =>
                                [
                                    'id'   => '48e2f093-65b6-4200-b7e5-981b841e2e27',
                                    'uuid' => '48e2f093-65b6-4200-b7e5-981b841e2e27',
                                ],
                            9 =>
                                [
                                    'id'   => '8135bb3e-e14a-4a24-a230-1dda1865692e',
                                    'uuid' => '8135bb3e-e14a-4a24-a230-1dda1865692e',
                                ]
                        ],
                    'container'        =>
                        [
                            'name'             => 'VMware Basic Monitoring (ESX directly)',
                            'parent_id'        => 1,
                            'containertype_id' => '9',
                        ]
                ]
        ];
        return $data;
    }
}
